@@ -1,6 +1,6 @@
 #!/bin/bash
 
-find "$@" -name '*.h' -o -name '*.cpp' -o -name '*.qml' -o -name '*.java'| grep -v /3rdparty/ | while read FILE; do
+find "$@" -name '*.h' -o -name '*.cpp' -o -name '*.qml' -o -name '*.java' -o -name "*.js" | grep -v /3rdparty/ | while read FILE; do
     if grep -qiE "Licensed under CC0." "$FILE" ; then continue; fi
     if grep -qiE "Copyright \(C\) [0-9, -]{4,} " "$FILE" ; then continue; fi
     thisfile=`basename $FILE`
