@@ -24,8 +24,10 @@
 #include "extractorinput.h"
 #include "extractorrepository.h"
 #include "generic/genericpdfextractor_p.h"
+#include "generic/genericicalextractor_p.h"
 #include "generic/genericpkpassextractor_p.h"
 #include "generic/genericuic918extractor_p.h"
+#include "generic/genericvdvextractor_p.h"
 #include "htmldocument.h"
 #include "iatabcbpparser.h"
 #include "jsonlddocument.h"
@@ -33,6 +35,7 @@
 #include "pdf/pdfdocument.h"
 #include "generic/structureddataextractor_p.h"
 #include "uic9183/uic9183parser.h"
+#include "vdv/vdvticketparser.h"
 
 #include "jsapi/barcode.h"
 #include "jsapi/context.h"
@@ -468,35 +471,56 @@ void ExtractorEnginePrivate::extractDocument()
         // if we didn't find anything, let's use whatever the generic extractors found
         if (m_result.empty()) {
             for (const auto &gr : m_genericResults) {
-                std::copy(gr.result.begin(), gr.result.end(), std::back_inserter(m_result));
+                const auto r = gr.jsonLdResult();
+                std::copy(r.begin(), r.end(), std::back_inserter(m_result));
             }
         }
     }
+
+    // set modification time for all results that don't have it yet
+    for (int i = 0; i < m_result.size(); ++i) {
+        auto res = m_result.at(i).toObject();
+        if (!res.contains(QLatin1String("modifiedTime"))) {
+            res.insert(QStringLiteral("modifiedTime"), m_context->m_senderDate.toString(Qt::ISODate));
+        }
+        m_result[i] = res;
+    }
 }
 
 void ExtractorEnginePrivate::extractGeneric()
 {
     if (m_htmlDoc) {
         const auto res = StructuredDataExtractor::extract(m_htmlDoc.get());
-        m_genericResults.emplace_back(GenericExtractor::Result{res, {}, -1});
+        m_genericResults.emplace_back(GenericExtractor::Result{res});
     }
     else if (m_pdfDoc) {
         m_genericResults = m_genericPdfExtractor.extract(m_pdfDoc.get());
     }
     else if (m_pass) {
-        m_genericResults.emplace_back(GenericExtractor::Result{{GenericPkPassExtractor::extract(m_pass.get(), m_context->m_senderDate)}, {}, -1});
+        m_genericResults.emplace_back(GenericPkPassExtractor::extract(m_pass.get(), m_context->m_senderDate));
     }
+#ifdef HAVE_KCAL
+    else if (m_calendar) {
+        m_genericResults = GenericIcalExtractor::extract(m_calendar);
+    }
+#endif
     else  if (!m_text.isEmpty()) {
         if (IataBcbpParser::maybeIataBcbp(m_text)) {
             const auto res = IataBcbpParser::parse(m_text, m_context->m_senderDate.date());
-            m_genericResults.emplace_back(GenericExtractor::Result{JsonLdDocument::toJson(res), m_text, -1});
+            m_genericResults.emplace_back(GenericExtractor::Result{res, m_text});
         }
     }
     else if (!m_data.isEmpty()) {
         if (Uic9183Parser::maybeUic9183(m_data)) {
             QJsonArray res;
             GenericUic918Extractor::extract(m_data, res, m_context->m_senderDate);
-            m_genericResults.emplace_back(GenericExtractor::Result{res, m_data, -1});
+            m_genericResults.emplace_back(GenericExtractor::Result{res, m_data});
+            return;
+        } else if (VdvTicketParser::maybeVdvTicket(m_data)) {
+            const auto res = GenericVdvExtractor::extract(m_data);
+            if (!res.isEmpty()) {
+                m_genericResults.emplace_back(GenericExtractor::Result(res, m_data));
+            }
             return;
         }
         // try again as text
@@ -514,7 +538,10 @@ void ExtractorEnginePrivate::determineExtractors()
         m_repo.extractorsForPass(m_pass.get(), m_extractors);
 #ifdef HAVE_KCAL
     } else if (m_calendar) {
-        m_repo.extractorsForCalendar(m_calendar, m_extractors);
+        m_repo.extractorsForCalendar(m_calendar.get(), m_extractors);
+        for (const auto &event : m_calendar->events()) {
+            m_repo.extractorsForEvent(event.get(), m_extractors);
+        }
 #endif
     }
     if (m_mimeContext) {
@@ -529,9 +556,9 @@ void ExtractorEnginePrivate::determineExtractors()
 
     for (const auto &genericResult : m_genericResults) {
         // check if generic extractors identified documents we have custom extractors for
-        m_repo.extractorsForJsonLd(genericResult.result, m_extractors);
+        m_repo.extractorsForJsonLd(genericResult.jsonLdResult(), m_extractors);
         // check the unrecognized (vendor-specific) barcodes, if any
-        m_repo.extractorsForBarcode(genericResult.barcode.toString(), m_extractors);
+        m_repo.extractorsForBarcode(genericResult.barcode().toString(), m_extractors);
     }
 }
 
@@ -593,11 +620,11 @@ void ExtractorEnginePrivate::extractCustomForGenericResults()
 {
     for (const auto &genericResult : m_genericResults) {
         // expose genericResult content to custom extractors via Context object
-        m_context->m_barcode = genericResult.barcode;
-        if (!genericResult.result.empty()) {
-            m_context->m_data = m_engine.toScriptValue(genericResult.result);
+        m_context->m_barcode = genericResult.barcode();
+        if (!genericResult.jsonLdResult().isEmpty()) {
+            m_context->m_data = m_engine.toScriptValue(genericResult.jsonLdResult());
         }
-        m_context->m_pdfPageNum = genericResult.pageNum;
+        m_context->m_pdfPageNum = genericResult.pageNumber();
 
         // check if generic extractors identified documents we have custom extractors for
         const auto prevResults = m_result.size();
@@ -606,7 +633,8 @@ void ExtractorEnginePrivate::extractCustomForGenericResults()
 
         // if this didn't find something, take the generic extractor result as-is
         if (prevResults == m_result.size()) {
-            std::copy(genericResult.result.begin(), genericResult.result.end(), std::back_inserter(m_result));
+            const auto r = genericResult.jsonLdResult();
+            std::copy(r.begin(), r.end(), std::back_inserter(m_result));
         }
     }
 }
@@ -642,7 +670,7 @@ void ExtractorEnginePrivate::executeScript(const Extractor &extractor)
         return;
     }
 
-    qCDebug(Log) << "Running custom extractor" << extractor.scriptFileName() << extractor.scriptFunction();
+    //qCDebug(Log) << "Running custom extractor" << extractor.scriptFileName() << extractor.scriptFunction();
     QJSValueList args;
     switch (extractor.type()) {
         case ExtractorInput::Text:
