@@ -22,13 +22,12 @@
 
 #include "kitinerary_export.h"
 
-#include <QSharedPointer>
-
 #include <memory>
 #include <vector>
 
 namespace KCalendarCore {
 class Calendar;
+class Event;
 }
 
 namespace KMime {
@@ -40,7 +39,9 @@ class Pass;
 }
 
 class QJsonArray;
+class QJsonValue;
 class QString;
+class QStringList;
 
 namespace KItinerary {
 
@@ -76,7 +77,9 @@ public:
     /** Finds matching extractors for the given barcode string. */
     void extractorsForBarcode(const QString &code, std::vector<Extractor> &extractors) const;
     /** Find matching extractors for the given iCal calendar. */
-    void extractorsForCalendar(const QSharedPointer<KCalendarCore::Calendar> &cal, std::vector<Extractor> &extractors) const;
+    void extractorsForCalendar(const KCalendarCore::Calendar *cal, std::vector<Extractor> &extractors) const;
+    /** Find matching extractors for the given iCal event. */
+    void extractorsForEvent(const KCalendarCore::Event *event, std::vector<Extractor> &extractors) const;
     /** Find matching extractors for the given content. */
     void extractorsForContent(const QString &content, std::vector<Extractor> &extractors) const;
     /** Returns the extractor with the given identifier. */
@@ -87,6 +90,13 @@ public:
     /** Sets additional search paths to look for extractors. */
     void setAdditionalSearchPaths(const QStringList &searchPaths);
 
+    ///@cond internal
+    /** JSON serialization of @p extractor, including all other Extractor definitions in the same file, if any.
+     *  Only for tooling, do not use otherwise.
+     */
+    QJsonValue extractorToJson(const Extractor &extractor) const;
+    ///@endcond
+
 private:
     ExtractorRepositoryPrivate* d;
 };
