@@ -129,7 +129,7 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
     if (JsonLd::isA<TrainReservation>(lhs)) {
         const auto lhsRes = lhs.value<TrainReservation>();
         const auto rhsRes = rhs.value<TrainReservation>();
-        if (lhsRes.reservationNumber() != rhsRes.reservationNumber()) {
+        if (conflictIfPresent(lhsRes.reservationNumber(), rhsRes.reservationNumber())) {
             return false;
         }
         return isSame(lhsRes.reservationFor(), rhsRes.reservationFor());
@@ -311,6 +311,16 @@ static bool isSameLineName(const QString &lhs, const QString &rhs)
 
 static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
 {
+    if (lhs.departureDay() != rhs.departureDay()) {
+        return false;
+    }
+
+    // for unbound tickets, comparing the line number below wont help
+    // so we have to use the slightly less robust location comparisson
+    if (!lhs.departureTime().isValid() && !rhs.departureTime().isValid()) {
+        return lhs.departureStation().name() == rhs.departureStation().name() && lhs.arrivalStation().name() == rhs.departureStation().name();
+    }
+
     if (lhs.trainNumber().isEmpty() || rhs.trainNumber().isEmpty()) {
         qCDebug(CompareLog) << "missing train number" << lhs.trainNumber() << rhs.trainNumber();
         return false;
@@ -537,6 +547,15 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
         return {};
     }
 
+    // prefer the element with the newer mtime, if we have that information
+    if (JsonLd::canConvert<Reservation>(lhs) && JsonLd::canConvert<Reservation>(rhs)) {
+        const auto lhsDt = JsonLd::convert<Reservation>(lhs).modifiedTime();
+        const auto rhsDt = JsonLd::convert<Reservation>(rhs).modifiedTime();
+        if (lhsDt.isValid() && rhsDt.isValid() && rhsDt < lhsDt) {
+            return MergeUtil::merge(rhs, lhs);
+        }
+    }
+
     auto res = lhs;
     const auto mo = QMetaType(res.userType()).metaObject();
     for (int i = 0; i < mo->propertyCount(); ++i) {
